@@ -29,9 +29,9 @@
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //-------------------------------------------------------------------------
 use num::{Float, One, Zero, Num, Signed};
-use std::fmt;
-use std::ops::{Add, Mul, Div, Sub, AddAssign, SubAssign, Neg};
-use std::ops::{Deref, DerefMut, Index, IndexMut};
+use core::fmt;
+use core::ops::{Add, Mul, Div, Sub, AddAssign, SubAssign, Neg};
+use core::ops::{Deref, DerefMut, Index, IndexMut};
 
 use crate::slices_methods::*;
 use crate::traits::LinearAlgebra;
@@ -58,7 +58,7 @@ impl<T> M55<T> {
     }
 }
 
-impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M55<T> {
+impl<T: Float + core::iter::Sum> LinearAlgebra<T> for M55<T> {
     fn rows(&self) -> usize {
         self.0.len()
     }
@@ -303,7 +303,7 @@ impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M55<T> {
                 normalize(&mut *q_tilde);
                 q[i] = q_tilde;
             }
-            let basis = V5::new([q[0], q[1], q[2], q[3], q[4]]);
+            let basis = V5::new_from(q[0], q[1], q[2], q[3], q[4]);
             let q     = M55::new_from_vecs(basis);
             let r     = q.transpose() * (*self);
             Some((q, r))
@@ -1004,7 +1004,6 @@ impl<T> IndexMut<(usize, usize)> for M55<T> {
 //-------------------------------------------------------------------------
 impl<T: Num + fmt::Display> fmt::Display for M55<T> {
     fn fmt(&self, dest: &mut fmt::Formatter) -> fmt::Result {
-        println!();
         write!(
             dest,
             "|{0:<7.2} {1:^7.2} {2:^7.2} {3:^7.2} {4:>7.2}|\n",
